@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::Author::PERLANCAR::NonCPAN;
 
-our $DATE = '2015-07-01'; # DATE
-our $VERSION = '0.39'; # VERSION
+our $DATE = '2015-07-10'; # DATE
+our $VERSION = '0.40'; # VERSION
 
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -13,7 +13,7 @@ sub configure {
 
     $self->add_bundle(Filter => {
         -bundle => '@Author::PERLANCAR',
-        -remove => [qw/ConfirmRelease UploadToCPAN/],
+        -remove => [qw/Authority ConfirmRelease UploadToCPAN/],
     });
 }
 
@@ -34,7 +34,7 @@ Dist::Zilla::PluginBundle::Author::PERLANCAR::NonCPAN - Dist::Zilla like PERLANC
 
 =head1 VERSION
 
-This document describes version 0.39 of Dist::Zilla::PluginBundle::Author::PERLANCAR::NonCPAN (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2015-07-01.
+This document describes version 0.40 of Dist::Zilla::PluginBundle::Author::PERLANCAR::NonCPAN (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2015-07-10.
 
 =head1 SYNOPSIS
 
@@ -45,11 +45,15 @@ is equivalent to:
 
  [@Filter]
  bundle=@Author::PERLANCAR
+ remove=Authority
  remove=ConfirmRelease
- remove=MetaJSON
- remove=MetaYAML
  remove=UploadToCPAN
 
+(Authority is removed so you can conveniently use this bundle and add the
+Authority plugin separately again and set C<authority>, instead of having to
+@Filter this bundle and remove Authority only to add it later to customize the
+authority.)
+
 =head1 DESCRIPTION
 
 =for Pod::Coverage ^(configure)$
