@@ -3,7 +3,7 @@ package Dist::Zilla::PluginBundle::Author::PERLANCAR::NonCPAN::Task;
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-our $VERSION = '0.39'; # VERSION
+our $VERSION = '0.40'; # VERSION
 
 use Dist::Zilla::PluginBundle::Filter;
 
@@ -12,7 +12,7 @@ sub configure {
 
     $self->add_bundle(Filter => {
         -bundle => '@Author::PERLANCAR::Task',
-        -remove => [qw/ConfirmRelease UploadToCPAN/],
+        -remove => [qw/Authority ConfirmRelease UploadToCPAN/],
     });
 }
 
@@ -33,7 +33,7 @@ Dist::Zilla::PluginBundle::Author::PERLANCAR::NonCPAN::Task - Dist::Zilla like P
 
 =head1 VERSION
 
-This document describes version 0.39 of Dist::Zilla::PluginBundle::Author::PERLANCAR::NonCPAN::Task (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2015-07-01.
+This document describes version 0.40 of Dist::Zilla::PluginBundle::Author::PERLANCAR::NonCPAN::Task (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2015-07-10.
 
 =head1 SYNOPSIS
 
@@ -44,9 +44,8 @@ is equivalent to:
 
  [@Filter]
  bundle=@Author::PERLANCAR::Task
+ remove=Authority
  remove=ConfirmRelease
- remove=MetaJSON
- remove=MetaYAML
  remove=UploadToCPAN
 
 =head1 DESCRIPTION
